@@ -61,6 +61,9 @@ apiEndpointText = "{{endpoint_text}}"
 {% if default_environment %}
 defaultSessionEnvironment = "{{default_environment}}"
 {% endif %}
+{% if default_import_environment %}
+defaultImportEnvironment = "{{default_import_environment}}"
+{% endif %}
 siteDescription = "{{site_description}}"
 connectionMode = "SESSION"
 signupSupport = {{signup_support}}
@@ -71,15 +74,19 @@ autoLogout = {{auto_logout}}
 
 [resources]
 openPortToPublic = {{open_port_to_public}}
-maxCPUCoresPerContainer = {{max_cpu_cores_per_container}}
-maxCUDADevicesPerContainer = {{max_cuda_devices_per_container}}
-maxCUDASharesPerContainer = {{max_cuda_shares_per_container}}
-maxShmPerContainer = {{max_shm_per_container}}
+maxCPUCoresPerSession = {{max_cpu_cores_per_session}}
+maxCUDADevicesPerSession = {{max_cuda_devices_per_session}}
+maxShmPerSession = {{max_shm_per_session}}
 maxFileUploadSize = {{max_file_upload_size}}
 
 [menu]
 blocklist = "{{menu_blocklist}}"
 
+{% if console_menu_plugins %}
+[plugin]
+page = "{{console_menu_plugins}}"
+
+{% endif %}
 [wsproxy]
 proxyURL = "{{proxy_url}}/"
 #proxyBaseURL =
@@ -139,25 +146,26 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             license_valid_until = ''
         if 'resources' in config:
             open_port_to_public = 'true' if config['resources'].get('open_port_to_public') else 'false'
-            max_cpu_cores_per_container = config['resources'].get('max_cpu_cores_per_container', 64)
-            max_cuda_devices_per_container = config['resources'].get(
-                    'max_cuda_devices_per_container', 16)
-            max_cuda_shares_per_container = config['resources'].get(
-                    'max_cuda_shares_per_container', 16)
-            max_shm_per_container = config['resources'].get('max_shm_per_container', 2)
+            max_cpu_cores_per_session = config['resources'].get('max_cpu_cores_per_session', 64)
+            max_cuda_devices_per_session = config['resources'].get('max_cuda_devices_per_session', 16)
+            max_shm_per_session = config['resources'].get('max_shm_per_session', 2)
             max_file_upload_size = config['resources'].get('max_file_upload_size', 4294967296)
         else:
             open_port_to_public = 'false'
-            max_cpu_cores_per_container = 64
-            max_cuda_devices_per_container = 16
-            max_cuda_shares_per_container = 16
-            max_shm_per_container = 2
+            max_cpu_cores_per_session = 64
+            max_cuda_devices_per_session = 16
+            max_shm_per_session = 2
             max_file_upload_size = 4294967296
+        if 'plugin' in config:
+            console_menu_plugins = config['plugin'].get('page', '')
+        else:
+            console_menu_plugins = False
         config_content = console_config_toml_template.render(**{
             'endpoint_url': f'{scheme}://{request.host}',  # must be absolute
             'endpoint_text': config['api']['text'],
             'site_description': config['ui']['brand'],
             'default_environment': config['ui'].get('default_environment'),
+            'default_import_environment': config['ui'].get('default_import_environment'),
             'proxy_url': config['service']['wsproxy']['url'],
             'signup_support': 'true' if config['service']['enable_signup'] else 'false',
             'allow_change_signin_mode':
@@ -169,12 +177,12 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
             'auto_logout':
                 'true' if config['service'].get('auto_logout') else 'false',
             'open_port_to_public': open_port_to_public,
-            'max_cpu_cores_per_container': max_cpu_cores_per_container,
-            'max_cuda_devices_per_container': max_cuda_devices_per_container,
-            'max_cuda_shares_per_container': max_cuda_shares_per_container,
-            'max_shm_per_container': max_shm_per_container,
+            'max_cpu_cores_per_session': max_cpu_cores_per_session,
+            'max_cuda_devices_per_session': max_cuda_devices_per_session,
+            'max_shm_per_session': max_shm_per_session,
             'max_file_upload_size': max_file_upload_size,
             'menu_blocklist': config['ui'].get('menu_blocklist', ''),
+            'console_menu_plugins': console_menu_plugins,
             'license_edition': license_edition,
             'license_valid_since': license_valid_since,
             'license_valid_until': license_valid_until,
@@ -196,10 +204,10 @@ async def console_handler(request: web.Request) -> web.StreamResponse:
 
 cache_patterns = {
     r'\.(?:manifest|appcache|html?|xml|json|ini|toml)$': {
-        'Cache-Control': 'no-cache, no-store, must-revalidate'
+        'Cache-Control': 'no-store'
     },
     r'(?:backend.ai-console.js)$': {
-        'Cache-Control': 'no-cache, no-store, must-revalidate'
+        'Cache-Control': 'no-store'
     },
     r'\.(?:jpg|jpeg|gif|png|ico|cur|gz|svg|svgz|mp4|ogg|ogv|webm|htc|woff|woff2)$': {
         'Cache-Control': 'max-age=259200, public',
@@ -208,7 +216,7 @@ cache_patterns = {
         'Cache-Control': 'max-age=86400, public, must-revalidate, proxy-revalidate',
     },
     r'\.(?:py|log?|txt)$': {
-        'Cache-Control': 'no-cache, no-store, must-revalidate'
+        'Cache-Control': 'no-store'
     },
 }
 _cache_patterns = {re.compile(k): v for k, v in cache_patterns.items()}
@@ -420,6 +428,7 @@ async def server_main(loop, pidx, args):
     cors.add(app.router.add_route('POST', '/func/{path:auth/signup}', anon_web_plugin_handler))
     cors.add(app.router.add_route('POST', '/func/{path:auth/signout}', web_handler))
     cors.add(app.router.add_route('GET', '/func/{path:stream/kernel/_/events}', web_handler))
+    cors.add(app.router.add_route('GET', '/func/{path:stream/session/[^/]+/apps$}', web_handler))
     cors.add(app.router.add_route('GET', '/func/{path:stream/.*$}', websocket_handler))
     cors.add(app.router.add_route('GET', '/func/', anon_web_handler))
     cors.add(app.router.add_route('HEAD', '/func/{path:.*$}', web_handler))
